@@ -60,6 +60,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
     __private_attributes__: Dict[str, Any]
     __sqla_table__: Table
     __exclude__: set
+    __relations__: dict
 
     # instance attrs
     __modified__: set
@@ -105,7 +106,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
             return super().__setattr__(name, value)
         if name in EXCLUDE_KEYS:
             return object.__setattr__(self, name, value)
-        if name not in self.__private_attributes__:
+        if name not in self.__private_attributes__ and name in self.__fields__:
             self.flag_modified(name)
         if name in self.__relations__:
             raise ValueError('Do not set relation field')
@@ -131,6 +132,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         if getattr(self, 'id', None) is None:
             raise OrmException('id must be set')
 
+    # pylint: disable=access-member-before-definition
     async def save(self):
         if self.__bound__:
             self.ensure_id()
